@@ -1,7 +1,7 @@
 """
 Type annotations for accessanalyzer service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/literals.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/literals/)
 
 Usage::
 
@@ -47,8 +47,11 @@ __all__ = (
     "ValidatePolicyFindingTypeType",
     "ValidatePolicyPaginatorName",
     "ValidatePolicyResourceTypeType",
+    "AccessAnalyzerServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
+    "RegionName",
 )
 
 
@@ -117,6 +120,7 @@ ValidatePolicyResourceTypeType = Literal[
     "AWS::S3::MultiRegionAccessPoint",
     "AWS::S3ObjectLambda::AccessPoint",
 ]
+AccessAnalyzerServiceName = Literal["accessanalyzer"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -148,6 +152,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -234,6 +239,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -270,6 +276,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -334,6 +341,7 @@ ServiceName = Literal[
     "pinpoint",
     "pinpoint-email",
     "pinpoint-sms-voice",
+    "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
     "proton",
@@ -418,6 +426,18 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal[
     "list_access_preview_findings",
     "list_access_previews",
@@ -428,3 +448,27 @@ PaginatorName = Literal[
     "list_policy_generations",
     "validate_policy",
 ]
+RegionName = Literal[
+    "af-south-1",
+    "ap-east-1",
+    "ap-northeast-1",
+    "ap-northeast-2",
+    "ap-northeast-3",
+    "ap-south-1",
+    "ap-southeast-1",
+    "ap-southeast-2",
+    "ap-southeast-3",
+    "ca-central-1",
+    "eu-central-1",
+    "eu-north-1",
+    "eu-south-1",
+    "eu-west-1",
+    "eu-west-2",
+    "eu-west-3",
+    "me-south-1",
+    "sa-east-1",
+    "us-east-1",
+    "us-east-2",
+    "us-west-1",
+    "us-west-2",
+]
